@@ -25,9 +25,9 @@
 /* This is the sidebar title widget, which is the title part of the sidebar. */
 
 #include <config.h>
+#include <math.h>
 #include "nautilus-sidebar-title.h"
 
-#include "nautilus-sidebar.h"
 #include "nautilus-window.h"
 
 #include <bonobo/bonobo-exception.h>
@@ -54,8 +54,8 @@
 #include <libnautilus-private/nautilus-metadata.h>
 #include <libnautilus-private/nautilus-search-uri.h>
 #include <libnautilus-private/nautilus-theme.h>
-#include <math.h>
 #include <string.h>
+#include <stdlib.h>
 
 /* maximum allowable size to be displayed as the title */
 #define MAX_TITLE_SIZE 		256
@@ -64,7 +64,6 @@
 
 #define MORE_INFO_FONT_SIZE 	 12
 #define MIN_TITLE_FONT_SIZE 	 12
-#define MAX_TITLE_FONT_SIZE 	 18
 #define TITLE_PADDING		  4
 
 static void                nautilus_sidebar_title_class_init (NautilusSidebarTitleClass *klass);
@@ -132,7 +131,9 @@ style_set (GtkWidget *widget,
 	/* Update the fixed-size "more info" font */
 	style = gtk_widget_get_style (widget);
 	font_desc = pango_font_description_copy (style->font_desc);
-	pango_font_description_set_size (font_desc, MORE_INFO_FONT_SIZE * PANGO_SCALE);
+	if (pango_font_description_get_size (font_desc) < MORE_INFO_FONT_SIZE * PANGO_SCALE) {
+		pango_font_description_set_size (font_desc, MORE_INFO_FONT_SIZE * PANGO_SCALE);
+	}
 	
 	gtk_widget_modify_font (sidebar_title->details->more_info_label,
 				font_desc);
@@ -367,7 +368,7 @@ update_icon (NautilusSidebarTitle *sidebar_title)
 
 	pixbuf = NULL;
 	if (icon_name != NULL && icon_name[0] != '\0') {
-		pixbuf = nautilus_icon_factory_get_pixbuf_from_name (icon_name, NULL, NAUTILUS_ICON_SIZE_LARGE);
+		pixbuf = nautilus_icon_factory_get_pixbuf_from_name (icon_name, NULL, NAUTILUS_ICON_SIZE_LARGE, NULL);
 	} else if (nautilus_icon_factory_is_icon_ready_for_file (sidebar_title->details->file)) {
 		pixbuf = nautilus_icon_factory_get_pixbuf_for_file (sidebar_title->details->file,
 								    "accept",
@@ -399,6 +400,7 @@ update_title_font (NautilusSidebarTitle *sidebar_title)
 	int available_width;
 	PangoFontDescription *title_font;
 	int largest_fitting_font_size;
+	int max_style_font_size;
 	GtkStyle *style;
 
 	/* Make sure theres work to do */
@@ -415,14 +417,21 @@ update_title_font (NautilusSidebarTitle *sidebar_title)
 
 	style = gtk_widget_get_style (GTK_WIDGET (sidebar_title));
 	title_font = pango_font_description_copy (style->font_desc);
+
+	max_style_font_size = pango_font_description_get_size (title_font) * 1.8 / PANGO_SCALE;
+	if (max_style_font_size < MIN_TITLE_FONT_SIZE) {
+		max_style_font_size = MIN_TITLE_FONT_SIZE + 1;
+	}
+
 	largest_fitting_font_size = eel_pango_font_description_get_largest_fitting_font_size (
 		title_font,
 		gtk_widget_get_pango_context (sidebar_title->details->title_label),
 		sidebar_title->details->title_text,
 		available_width,
 		MIN_TITLE_FONT_SIZE,
-		MAX_TITLE_FONT_SIZE);
-	pango_font_description_set_size (title_font, largest_fitting_font_size * PANGO_SCALE);
+		max_style_font_size);
+	pango_font_description_set_size (title_font, largest_fitting_font_size * PANGO_SCALE); 
+
 	pango_font_description_set_weight (title_font, PANGO_WEIGHT_BOLD);
 	
 	gtk_widget_modify_font (sidebar_title->details->title_label,
@@ -575,17 +584,17 @@ update_emblems (NautilusSidebarTitle *sidebar_title)
 	/* loop through the list of emblems, installing them in the box */
 	for (p = icons; p != NULL; p = p->next) {
 		pixbuf = nautilus_icon_factory_get_pixbuf_for_icon
-			(p->data,
-			 NAUTILUS_ICON_SIZE_STANDARD, NAUTILUS_ICON_SIZE_STANDARD,
-			 NAUTILUS_ICON_SIZE_STANDARD, NAUTILUS_ICON_SIZE_STANDARD,
-			 NULL, FALSE);
+			(p->data, NULL,
+			 NAUTILUS_ICON_SIZE_STANDARD,
+			 NULL, NULL,
+			 FALSE, NULL);
 		if (pixbuf != NULL) {
 			add_emblem (sidebar_title, pixbuf);
 			g_object_unref (pixbuf);
 		}
 	}
 	
-	nautilus_scalable_icon_list_free (icons);
+	eel_g_list_free_deep (icons);
 }
 
 static void
@@ -635,7 +644,7 @@ item_count_ready (NautilusSidebarTitle *sidebar_title)
 static void
 monitor_add (NautilusSidebarTitle *sidebar_title)
 {
-	GList *attributes;
+	NautilusFileAttributes attributes;
 
 	/* Monitor the things needed to get the right icon. Don't
 	 * monitor a directory's item count at first even though the
@@ -650,16 +659,13 @@ monitor_add (NautilusSidebarTitle *sidebar_title)
 	sidebar_title->details->monitoring_count = item_count_ready (sidebar_title);
 
 	attributes = nautilus_icon_factory_get_required_file_attributes ();		
-	attributes = g_list_prepend (attributes,
-				     NAUTILUS_FILE_ATTRIBUTE_METADATA);
+	attributes |= NAUTILUS_FILE_ATTRIBUTE_METADATA;
+	
 	if (sidebar_title->details->monitoring_count) {
-		attributes = g_list_prepend (attributes,
-					     NAUTILUS_FILE_ATTRIBUTE_DIRECTORY_ITEM_COUNT);
+		attributes |= NAUTILUS_FILE_ATTRIBUTE_DIRECTORY_ITEM_COUNT;
 	}
 
 	nautilus_file_monitor_add (sidebar_title->details->file, sidebar_title, attributes);
-
-	g_list_free (attributes);
 }
 
 static void
