@@ -133,27 +133,23 @@ nautilus_switchable_search_bar_new (NautilusWindow *window)
 	bar->complex_search_bar = nautilus_complex_search_bar_new (window);
 	bar->simple_search_bar = nautilus_simple_search_bar_new (window);
 
-	gtk_signal_connect_object (GTK_OBJECT (bar->complex_search_bar),
-				   "location_changed",
-				   G_CALLBACK (nautilus_navigation_bar_location_changed),
-				   GTK_OBJECT (bar));
-	gtk_signal_connect_object (GTK_OBJECT (bar->simple_search_bar),
-				   "location_changed",
-				   G_CALLBACK (nautilus_navigation_bar_location_changed),
-				   GTK_OBJECT (bar));
+	g_signal_connect_object (bar->complex_search_bar, "location_changed",
+				 G_CALLBACK (nautilus_navigation_bar_location_changed),
+				 bar, G_CONNECT_SWAPPED);
+	g_signal_connect_object (bar->simple_search_bar, "location_changed",
+				 G_CALLBACK (nautilus_navigation_bar_location_changed),
+				 bar, G_CONNECT_SWAPPED);
 
 	
-	gtk_box_pack_start  (GTK_BOX (hbox), bar->complex_search_bar, TRUE, TRUE,
-			     0);
-	gtk_box_pack_start  (GTK_BOX (hbox), bar->simple_search_bar, TRUE, TRUE,
-			     0);
+	gtk_box_pack_start  (GTK_BOX (hbox), bar->complex_search_bar, TRUE, TRUE, 0);
+	gtk_box_pack_start  (GTK_BOX (hbox), bar->simple_search_bar, TRUE, TRUE, 0);
 	
 	gtk_container_add (GTK_CONTAINER (bar), hbox);
 
 	gtk_widget_show_all (hbox);
 	nautilus_switchable_search_bar_set_mode 
 		(bar, 
-		 eel_preferences_get_integer (NAUTILUS_PREFERENCES_SEARCH_BAR_TYPE));
+		 eel_preferences_get_enum (NAUTILUS_PREFERENCES_SEARCH_BAR_TYPE));
 	
 	/* React to future preference changes. */
 	eel_preferences_add_callback (NAUTILUS_PREFERENCES_SEARCH_BAR_TYPE,
@@ -280,12 +276,11 @@ nautilus_search_uri_to_search_bar_mode (const char *uri)
 {
 	NautilusSearchBarMode preferred_mode;
 
-	preferred_mode = eel_preferences_get_integer (NAUTILUS_PREFERENCES_SEARCH_BAR_TYPE);
+	preferred_mode = eel_preferences_get_enum (NAUTILUS_PREFERENCES_SEARCH_BAR_TYPE);
 	if (nautilus_search_uri_is_displayable_by_mode (uri, preferred_mode)) {
 		return preferred_mode;
-	}
-	else {
-		return (other_search_mode (preferred_mode));
+	} else {
+		return other_search_mode (preferred_mode);
 	}
 }
 
